pub enum Cadence {
EveryWeeks(CadenceWeeks),
AsNeeded,
GroomerRecommended,
Unknown,
}Expand description
Rebooking cadence source used for due-date prompts and groomer-recommended follow-up.
Variants
EveryWeeks(CadenceWeeks)
Staff can see the every weeks grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
AsNeeded
Staff can see the as needed grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
GroomerRecommended
Staff can see the groomer recommended grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
Unknown
Provider role or status could not be mapped confidently.