pub enum Rationale {
LastCompletedServiceCadence,
NoCompletedHistory,
GroomerRecommendedCadenceRequired,
}Expand description
Reason explaining why a grooming rebooking prompt is due or needs groomer input.
Variants
LastCompletedServiceCadence
Staff can see the last completed service cadence grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
NoCompletedHistory
Staff can see the no completed history grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
GroomerRecommendedCadenceRequired
Staff can see the groomer recommended cadence required grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.