pub enum Status {
DueLater,
DueNow,
Overdue,
NeedsGroomerRecommendation,
}Expand description
Normalized reservation states observed during source-data ingestion.
Variants
DueLater
Staff can see the due later grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
DueNow
Staff can see the due now grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
Overdue
Staff can see the overdue grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.
NeedsGroomerRecommendation
Staff can see the needs groomer recommendation grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.