pub struct Policy;Expand description
Grooming policy object that turns local rules into staff review decisions.
Implementations
Sourceimpl Policy
impl Policy
Sourcepub fn recommend_from_history(
&self,
pet_id: PetId,
history: &[ServiceHistoryEntry],
cadence: Cadence,
today: NaiveDate,
) -> Recommendation
pub fn recommend_from_history( &self, pet_id: PetId, history: &[ServiceHistoryEntry], cadence: Cadence, today: NaiveDate, ) -> Recommendation
Returns the recommend from history value used by grooming schedule/rebooking review.