pub enum Rationale {
LastCompletedServiceCadence,
NoCompletedHistory,
GroomerRecommendedCadenceRequired,
}Expand description
Decision vocabulary for rationale in grooming workflows.
Variants
LastCompletedServiceCadence
Last completed service cadence grooming operational signal for schedule, estimate, history, or review handling.
NoCompletedHistory
No completed history grooming operational signal for schedule, estimate, history, or review handling.
GroomerRecommendedCadenceRequired
Groomer recommended cadence required grooming operational signal for schedule, estimate, history, or review handling.