pub struct Policy;Expand description
Represents the policy concept as a typed grooming operational contract instead of a raw primitive.
Implementations
Sourceimpl Policy
impl Policy
Sourcepub fn recommend_from_history(
&self,
pet_id: PetId,
history: &[ServiceHistoryEntry],
cadence: Cadence,
today: NaiveDate,
) -> Recommendation
pub fn recommend_from_history( &self, pet_id: PetId, history: &[ServiceHistoryEntry], cadence: Cadence, today: NaiveDate, ) -> Recommendation
Returns the recommend from history evidence recorded on this grooming contract.